import React, { useState, useEffect } from "react";
import LeftNavigationUiConfiguratorTest from "./LeftNavigationUiConfiguratorTest";
import { Form, Row, Col, Button, Table } from "react-bootstrap";
import { FaEdit, FaUserAlt, FaBan } from "react-icons/fa";
import { Link, NavLink } from "react-router-dom";
import Alert from "react-bootstrap/Alert";
import axios from "axios";
import { useLocation } from "react-router-dom";

function UpdatePlanetEnvironmentTest(props) {
  const location = useLocation();
  const [successMessage, setSuccessMessage] = useState("");
  const [errorMessage, setErrorMessage] = useState("");
  const [planetEnvInfoData, setPlanetEnvInfoData] = useState({
    id: "",
    name: "",
    vhost: [
      {
        id: "",
        envName: "",
        name: "",
        protocol: "",
        port: "",
        cname: "",
      },
    ],
  });

  //load existing planet environment details
  useEffect(() => {
    axios
      .get(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/${new URLSearchParams(
          location.search
        ).get("planetId")}/orgs/${new URLSearchParams(location.search).get(
          "orgId"
        )}/env/${new URLSearchParams(location.search).get("envId")}`
      )
      .then((response) => {
        setPlanetEnvInfoData({
          id: response.data.id,
          name: response.data.name,
          vhost: response.data.vhost.map((vhdata, idex) => ({
            id: vhdata.id,
            envName: vhdata.envName,
            name: vhdata.name,
            protocol: vhdata.protocol,
            port: vhdata.port,
            cname: vhdata.cname,
          })),
        });
      })
      .catch((error) => {
        setErrorMessage(error.message);
      });
  }, []);

  //environment name change
  const handlePlanetEnvChange = (e) => {
    let temp = { ...planetEnvInfoData };
    temp[e.target.name] = e.target.value;
    setPlanetEnvInfoData(temp);
  };

  //submit handler
  const updatePlanetEnvSubmitHandler = (e) => {
    console.log(planetEnvInfoData);
    axios
      .put(
        `https://configurator-api-m7mkmev5sq-uc.a.run.app/planet/${new URLSearchParams(
          location.search
        ).get("planetId")}/orgs/${new URLSearchParams(location.search).get(
          "orgId"
        )}/env/${new URLSearchParams(location.search).get("envId")}`,
        planetEnvInfoData
      )
      .then((res) => {
        setSuccessMessage("Environment configuration updated successfully");
      })
      .catch((err) => {
        setErrorMessage(err.message);
      });
  };

  return (
    <section>
      <div className="developer-list-page">
        <div className="container">
          <div className="col-sm-12">
            <h2>Update Planet Env Info</h2>
            <ul className="breadcrumb">
              <li className="breadcrumb-item">
                <a href="/">Home</a>
              </li>
              <li className="breadcrumb-item active">
                <a href="/">Update Planet Env Info</a>
              </li>
            </ul>
          </div>
        </div>
      </div>
      <main id="main mt-5">
        {errorMessage && <Alert variant={"danger"}>{errorMessage}</Alert>}
        {successMessage && <Alert variant={"success"}>{successMessage}</Alert>}
        <section id="subpage" className="wow fadeInUp">
          <div className="upload-swagger">
            <div className="container">
              <div className="row form-section nopadding">
                <div className="col-lg-3">{props.leftNavigation}</div>
                <div className="col-lg-9 col-sm-12 swag-border-left">
                  <div className="pageHeaders">
                    <div className="mb-3">
                      <Form>
                        <Form.Group as={Row} controlId="planetEnvName">
                          <Form.Label column sm={2}>
                            Name{" "}
                          </Form.Label>
                          <Col sm={10}>
                            <Form.Control
                              type="text"
                              className="w-75"
                              name="name"
                              onChange={handlePlanetEnvChange}
                              value={planetEnvInfoData.name}
                            />
                          </Col>
                        </Form.Group>
                      </Form>

                      <br />
                      <br />
                      <Button
                        variant="primary"
                        onClick={updatePlanetEnvSubmitHandler}
                      >
                        Update
                      </Button>
                    </div>
                  </div>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </section>
  );
}

export default UpdatePlanetEnvironmentTest;
